@@ -75,7 +75,7 @@ def wait_for_tests(sha, owner, name, retry_interval=30):
 
     start_time = datetime.now()
 
-    while build['status'] in ['running', 'waiting', 'scheduled', 'not_running']:
+    while not build.get('stop_time'):
         if datetime.now() < start_time + timedelta(minutes=MAX_WAIT_MINUTES):
             sys.stdout.write('.')
             sys.stdout.flush()
@@ -92,4 +92,7 @@ def wait_for_tests(sha, owner, name, retry_interval=30):
     # guards to prevent false positives
     assert build['build_time_millis'] > 0
 
+    if build['status'] not in ['success', 'fixed']:
+        raise ValueError("Build failed with status %(status)s" % build)
+
     return build
